Class: Google::Cloud::Maintenance::Api::V1::ListResourceMaintenancesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Maintenance::Api::V1::ListResourceMaintenancesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb
Overview
The request structure for the ListResourceMaintenances method.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Filter the list as specified in https://google.aip.dev/160.
-
#order_by ⇒ ::String
Order results as specified in https://google.aip.dev/132.
-
#page_size ⇒ ::Integer
The maximum number of resource maintenances to send per page.
-
#page_token ⇒ ::String
The page token: If the next_page_token from a previous response is provided, this request will send the subsequent page.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Filter the list as specified in https://google.aip.dev/160.
356 357 358 359 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 356 class ListResourceMaintenancesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#order_by ⇒ ::String
Returns Order results as specified in https://google.aip.dev/132.
356 357 358 359 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 356 class ListResourceMaintenancesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns The maximum number of resource maintenances to send per page.
356 357 358 359 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 356 class ListResourceMaintenancesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns The page token: If the next_page_token from a previous response is provided, this request will send the subsequent page.
356 357 358 359 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 356 class ListResourceMaintenancesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent of the resource maintenance.
356 357 358 359 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 356 class ListResourceMaintenancesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |