Class: Google::Cloud::Maintenance::Api::V1::ListResourceMaintenancesResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Maintenance::Api::V1::ListResourceMaintenancesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb
Overview
The response structure for the ListResourceMaintenances method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
If present, the next page token can be provided to a subsequent ListResourceMaintenances call to list the next page.
-
#resource_maintenances ⇒ ::Array<::Google::Cloud::Maintenance::Api::V1::ResourceMaintenance>
The resulting resource maintenances.
-
#unreachable ⇒ ::Array<::String>
Locations that could not be reached.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns If present, the next page token can be provided to a subsequent ListResourceMaintenances call to list the next page. If empty, there are no more pages.
373 374 375 376 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 373 class ListResourceMaintenancesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resource_maintenances ⇒ ::Array<::Google::Cloud::Maintenance::Api::V1::ResourceMaintenance>
Returns The resulting resource maintenances.
373 374 375 376 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 373 class ListResourceMaintenancesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Locations that could not be reached.
373 374 375 376 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 373 class ListResourceMaintenancesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |