Class: Google::Cloud::Maintenance::Api::V1::Maintenance::Rest::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/maintenance/api/v1/maintenance/rest/client.rb

Overview

REST client for the Maintenance service.

Unified Maintenance service

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#location_path, #resource_maintenance_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new Maintenance REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Maintenance::Api::V1::Maintenance::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Maintenance::Api::V1::Maintenance::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Maintenance client.

Yield Parameters:



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/google/cloud/maintenance/api/v1/maintenance/rest/client.rb', line 128

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @maintenance_stub = ::Google::Cloud::Maintenance::Api::V1::Maintenance::Rest::ServiceStub.new(
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    credentials: credentials,
    logger: @config.logger
  )

  @maintenance_stub.logger(stub: true)&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end

  @location_client = Google::Cloud::Location::Locations::Rest::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @maintenance_stub.endpoint
    config.universe_domain = @maintenance_stub.universe_domain
    config.bindings_override = @config.bindings_override
    config.logger = @maintenance_stub.logger if config.respond_to? :logger=
  end
end

Instance Attribute Details

#location_clientGoogle::Cloud::Location::Locations::Rest::Client (readonly)

Get the associated client for mix-in of the Locations.

Returns:

  • (Google::Cloud::Location::Locations::Rest::Client)


184
185
186
# File 'lib/google/cloud/maintenance/api/v1/maintenance/rest/client.rb', line 184

def location_client
  @location_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the Maintenance Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all Maintenance clients
::Google::Cloud::Maintenance::Api::V1::Maintenance::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/google/cloud/maintenance/api/v1/maintenance/rest/client.rb', line 66

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Maintenance", "Api", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the Maintenance Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



98
99
100
101
# File 'lib/google/cloud/maintenance/api/v1/maintenance/rest/client.rb', line 98

def configure
  yield @config if block_given?
  @config
end

#get_resource_maintenance(request, options = nil) ⇒ ::Google::Cloud::Maintenance::Api::V1::ResourceMaintenance #get_resource_maintenance(name: nil) ⇒ ::Google::Cloud::Maintenance::Api::V1::ResourceMaintenance

Retrieve a single resource maintenance.

Examples:

Basic example

require "google/cloud/maintenance/api/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Maintenance::Api::V1::Maintenance::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Maintenance::Api::V1::GetResourceMaintenanceRequest.new

# Call the get_resource_maintenance method.
result = client.get_resource_maintenance request

# The returned object is of type Google::Cloud::Maintenance::Api::V1::ResourceMaintenance.
p result

Overloads:

  • #get_resource_maintenance(request, options = nil) ⇒ ::Google::Cloud::Maintenance::Api::V1::ResourceMaintenance

    Pass arguments to get_resource_maintenance via a request object, either of type GetResourceMaintenanceRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Maintenance::Api::V1::GetResourceMaintenanceRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_resource_maintenance(name: nil) ⇒ ::Google::Cloud::Maintenance::Api::V1::ResourceMaintenance

    Pass arguments to get_resource_maintenance via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The resource name of the resource within a service.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/google/cloud/maintenance/api/v1/maintenance/rest/client.rb', line 432

def get_resource_maintenance request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Maintenance::Api::V1::GetResourceMaintenanceRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_resource_maintenance..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Maintenance::Api::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_resource_maintenance.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_resource_maintenance.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @maintenance_stub.get_resource_maintenance request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_resource_maintenances(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Maintenance::Api::V1::ResourceMaintenance> #list_resource_maintenances(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Maintenance::Api::V1::ResourceMaintenance>

Retrieve a collection of resource maintenances.

Examples:

Basic example

require "google/cloud/maintenance/api/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Maintenance::Api::V1::Maintenance::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Maintenance::Api::V1::ListResourceMaintenancesRequest.new

# Call the list_resource_maintenances method.
result = client.list_resource_maintenances request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Maintenance::Api::V1::ResourceMaintenance.
  p item
end

Overloads:

  • #list_resource_maintenances(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Maintenance::Api::V1::ResourceMaintenance>

    Pass arguments to list_resource_maintenances via a request object, either of type ListResourceMaintenancesRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Maintenance::Api::V1::ListResourceMaintenancesRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_resource_maintenances(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Maintenance::Api::V1::ResourceMaintenance>

    Pass arguments to list_resource_maintenances via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent of the resource maintenance.

    • page_size (::Integer) (defaults to: nil)

      The maximum number of resource maintenances to send per page.

    • page_token (::String) (defaults to: nil)

      The page token: If the next_page_token from a previous response is provided, this request will send the subsequent page.

    • filter (::String) (defaults to: nil)

      Filter the list as specified in https://google.aip.dev/160.

    • order_by (::String) (defaults to: nil)

      Order results as specified in https://google.aip.dev/132.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
# File 'lib/google/cloud/maintenance/api/v1/maintenance/rest/client.rb', line 352

def list_resource_maintenances request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Maintenance::Api::V1::ListResourceMaintenancesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_resource_maintenances..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Maintenance::Api::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_resource_maintenances.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_resource_maintenances.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @maintenance_stub.list_resource_maintenances request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @maintenance_stub, :list_resource_maintenances, "resource_maintenances", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


191
192
193
# File 'lib/google/cloud/maintenance/api/v1/maintenance/rest/client.rb', line 191

def logger
  @maintenance_stub.logger
end

#summarize_maintenances(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Maintenance::Api::V1::MaintenanceSummary> #summarize_maintenances(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Maintenance::Api::V1::MaintenanceSummary>

Retrieves the statistics of a specific maintenance.

Examples:

Basic example

require "google/cloud/maintenance/api/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Maintenance::Api::V1::Maintenance::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Maintenance::Api::V1::SummarizeMaintenancesRequest.new

# Call the summarize_maintenances method.
result = client.summarize_maintenances request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Maintenance::Api::V1::MaintenanceSummary.
  p item
end

Overloads:

  • #summarize_maintenances(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Maintenance::Api::V1::MaintenanceSummary>

    Pass arguments to summarize_maintenances via a request object, either of type SummarizeMaintenancesRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Maintenance::Api::V1::SummarizeMaintenancesRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #summarize_maintenances(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Maintenance::Api::V1::MaintenanceSummary>

    Pass arguments to summarize_maintenances via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent of the resource maintenance. eg. projects/123/locations/*

    • page_size (::Integer) (defaults to: nil)

      The maximum number of resource maintenances to send per page. The default page size is 20 and the maximum is 1000.

    • page_token (::String) (defaults to: nil)

      The page token: If the next_page_token from a previous response is provided, this request will send the subsequent page.

    • filter (::String) (defaults to: nil)

      Filter the list as specified in https://google.aip.dev/160. Supported fields include:

      • maintenance.maintenanceName Examples:
      • maintenance.maintenanceName="eb3b709c-9ca1-5472-9fb6-800a3849eda1"
    • order_by (::String) (defaults to: nil)

      Order results as specified in https://google.aip.dev/132.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/google/cloud/maintenance/api/v1/maintenance/rest/client.rb', line 259

def summarize_maintenances request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Maintenance::Api::V1::SummarizeMaintenancesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.summarize_maintenances..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Maintenance::Api::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.summarize_maintenances.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.summarize_maintenances.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @maintenance_stub.summarize_maintenances request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @maintenance_stub, :summarize_maintenances, "maintenances", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


108
109
110
# File 'lib/google/cloud/maintenance/api/v1/maintenance/rest/client.rb', line 108

def universe_domain
  @maintenance_stub.universe_domain
end