Class: Google::Cloud::Maintenance::Api::V1::MaintenanceControl

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb

Overview

The control of the maintenance.

Defined Under Namespace

Modules: Control

Instance Attribute Summary collapse

Instance Attribute Details

#control::Google::Cloud::Maintenance::Api::V1::MaintenanceControl::Control

Returns The control of the resource maintenance.

Returns:



319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 319

class MaintenanceControl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Sets the type of control supported. comment (as in logs).
  module Control
    # Unspecified control.
    CONTROL_UNSPECIFIED = 0

    # Apply control.
    APPLY = 1

    # Manage policy control.
    MANAGE_POLICY = 2

    # Reschedule control.
    RESCHEDULE = 3
  end
end

#documentation::String

Returns Link to Service Producer documentation about maintenance control. Provided only when isCustom is true.

Returns:

  • (::String)

    Link to Service Producer documentation about maintenance control. Provided only when isCustom is true.



319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 319

class MaintenanceControl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Sets the type of control supported. comment (as in logs).
  module Control
    # Unspecified control.
    CONTROL_UNSPECIFIED = 0

    # Apply control.
    APPLY = 1

    # Manage policy control.
    MANAGE_POLICY = 2

    # Reschedule control.
    RESCHEDULE = 3
  end
end

#is_custom::Boolean

Returns Indicates whether the control is available only in Service Producer API (not through Unified Maintenance).

Returns:

  • (::Boolean)

    Indicates whether the control is available only in Service Producer API (not through Unified Maintenance).



319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 319

class MaintenanceControl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Sets the type of control supported. comment (as in logs).
  module Control
    # Unspecified control.
    CONTROL_UNSPECIFIED = 0

    # Apply control.
    APPLY = 1

    # Manage policy control.
    MANAGE_POLICY = 2

    # Reschedule control.
    RESCHEDULE = 3
  end
end