Class: Google::Cloud::Maintenance::Api::V1::MaintenanceSummary

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb

Overview

MaintenanceSummary contains maintenance statistics calculated based on ResourceMaintenances within the scope: project and location.

Defined Under Namespace

Classes: Aggregate, Stats

Instance Attribute Summary collapse

Instance Attribute Details

#category::Google::Cloud::Maintenance::Api::V1::MaintenanceCategory (readonly)

Returns Output only. The category of the maintenance event.

Returns:



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 115

class MaintenanceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Stats indicates the type of aggregate and the corresponding aggregates.
  # @!attribute [rw] group_by
  #   @return [::String]
  #     groupBy specifies the type of aggregate.
  #     For example a group_by might be `"state"`
  # @!attribute [rw] aggregates
  #   @return [::Array<::Google::Cloud::Maintenance::Api::V1::MaintenanceSummary::Aggregate>]
  #     Aggregates is a list <group, count> pairs. For example, if the
  #     group_by is `"state"` a possible tuple in the aggregates list could be
  #     "SCHEDULED" : `11`,
  class Stats
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Aggregate is a <group, count> pair.
  # @!attribute [rw] group
  #   @return [::String]
  #     Specifies what specific value of the group_by the count represents. For
  #     example if group_by is `"state"` its corresponding group could be
  #     `"SCHEDULED"`.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The count of the group.
  class Aggregate
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#controls::Array<::Google::Cloud::Maintenance::Api::V1::MaintenanceControl> (readonly)

Returns Output only. Control available for that Maintenance (might not be available for every resource that maintenance is applied to).

Returns:



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 115

class MaintenanceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Stats indicates the type of aggregate and the corresponding aggregates.
  # @!attribute [rw] group_by
  #   @return [::String]
  #     groupBy specifies the type of aggregate.
  #     For example a group_by might be `"state"`
  # @!attribute [rw] aggregates
  #   @return [::Array<::Google::Cloud::Maintenance::Api::V1::MaintenanceSummary::Aggregate>]
  #     Aggregates is a list <group, count> pairs. For example, if the
  #     group_by is `"state"` a possible tuple in the aggregates list could be
  #     "SCHEDULED" : `11`,
  class Stats
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Aggregate is a <group, count> pair.
  # @!attribute [rw] group
  #   @return [::String]
  #     Specifies what specific value of the group_by the count represents. For
  #     example if group_by is `"state"` its corresponding group could be
  #     `"SCHEDULED"`.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The count of the group.
  class Aggregate
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#description::String (readonly)

Returns Output only. The description of the maintenance.

Returns:

  • (::String)

    Output only. The description of the maintenance.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 115

class MaintenanceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Stats indicates the type of aggregate and the corresponding aggregates.
  # @!attribute [rw] group_by
  #   @return [::String]
  #     groupBy specifies the type of aggregate.
  #     For example a group_by might be `"state"`
  # @!attribute [rw] aggregates
  #   @return [::Array<::Google::Cloud::Maintenance::Api::V1::MaintenanceSummary::Aggregate>]
  #     Aggregates is a list <group, count> pairs. For example, if the
  #     group_by is `"state"` a possible tuple in the aggregates list could be
  #     "SCHEDULED" : `11`,
  class Stats
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Aggregate is a <group, count> pair.
  # @!attribute [rw] group
  #   @return [::String]
  #     Specifies what specific value of the group_by the count represents. For
  #     example if group_by is `"state"` its corresponding group could be
  #     `"SCHEDULED"`.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The count of the group.
  class Aggregate
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#maintenance_end_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Actual date when the maintenance successfully completed. Field present only after the state changed to SUCCEEDED.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. Actual date when the maintenance successfully completed. Field present only after the state changed to SUCCEEDED.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 115

class MaintenanceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Stats indicates the type of aggregate and the corresponding aggregates.
  # @!attribute [rw] group_by
  #   @return [::String]
  #     groupBy specifies the type of aggregate.
  #     For example a group_by might be `"state"`
  # @!attribute [rw] aggregates
  #   @return [::Array<::Google::Cloud::Maintenance::Api::V1::MaintenanceSummary::Aggregate>]
  #     Aggregates is a list <group, count> pairs. For example, if the
  #     group_by is `"state"` a possible tuple in the aggregates list could be
  #     "SCHEDULED" : `11`,
  class Stats
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Aggregate is a <group, count> pair.
  # @!attribute [rw] group
  #   @return [::String]
  #     Specifies what specific value of the group_by the count represents. For
  #     example if group_by is `"state"` its corresponding group could be
  #     `"SCHEDULED"`.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The count of the group.
  class Aggregate
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#maintenance_name::String (readonly)

Returns Output only. The name of the maintenance.

Returns:

  • (::String)

    Output only. The name of the maintenance.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 115

class MaintenanceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Stats indicates the type of aggregate and the corresponding aggregates.
  # @!attribute [rw] group_by
  #   @return [::String]
  #     groupBy specifies the type of aggregate.
  #     For example a group_by might be `"state"`
  # @!attribute [rw] aggregates
  #   @return [::Array<::Google::Cloud::Maintenance::Api::V1::MaintenanceSummary::Aggregate>]
  #     Aggregates is a list <group, count> pairs. For example, if the
  #     group_by is `"state"` a possible tuple in the aggregates list could be
  #     "SCHEDULED" : `11`,
  class Stats
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Aggregate is a <group, count> pair.
  # @!attribute [rw] group
  #   @return [::String]
  #     Specifies what specific value of the group_by the count represents. For
  #     example if group_by is `"state"` its corresponding group could be
  #     `"SCHEDULED"`.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The count of the group.
  class Aggregate
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#maintenance_scheduled_end_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. An estimated (best effort, not guaranteed) end time of the scheduled maintenance.

Returns:



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 115

class MaintenanceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Stats indicates the type of aggregate and the corresponding aggregates.
  # @!attribute [rw] group_by
  #   @return [::String]
  #     groupBy specifies the type of aggregate.
  #     For example a group_by might be `"state"`
  # @!attribute [rw] aggregates
  #   @return [::Array<::Google::Cloud::Maintenance::Api::V1::MaintenanceSummary::Aggregate>]
  #     Aggregates is a list <group, count> pairs. For example, if the
  #     group_by is `"state"` a possible tuple in the aggregates list could be
  #     "SCHEDULED" : `11`,
  class Stats
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Aggregate is a <group, count> pair.
  # @!attribute [rw] group
  #   @return [::String]
  #     Specifies what specific value of the group_by the count represents. For
  #     example if group_by is `"state"` its corresponding group could be
  #     `"SCHEDULED"`.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The count of the group.
  class Aggregate
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#maintenance_scheduled_start_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Scheduled start time of the maintenance. The maintenance will start at maintenanceScheduledStartTime or later, with best effort to finish before maintenanceScheduledEndTime.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. Scheduled start time of the maintenance. The maintenance will start at maintenanceScheduledStartTime or later, with best effort to finish before maintenanceScheduledEndTime.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 115

class MaintenanceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Stats indicates the type of aggregate and the corresponding aggregates.
  # @!attribute [rw] group_by
  #   @return [::String]
  #     groupBy specifies the type of aggregate.
  #     For example a group_by might be `"state"`
  # @!attribute [rw] aggregates
  #   @return [::Array<::Google::Cloud::Maintenance::Api::V1::MaintenanceSummary::Aggregate>]
  #     Aggregates is a list <group, count> pairs. For example, if the
  #     group_by is `"state"` a possible tuple in the aggregates list could be
  #     "SCHEDULED" : `11`,
  class Stats
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Aggregate is a <group, count> pair.
  # @!attribute [rw] group
  #   @return [::String]
  #     Specifies what specific value of the group_by the count represents. For
  #     example if group_by is `"state"` its corresponding group could be
  #     `"SCHEDULED"`.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The count of the group.
  class Aggregate
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#maintenance_start_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Actual date when the maintenance started. Field present only after the state changed to RUNNING.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. Actual date when the maintenance started. Field present only after the state changed to RUNNING.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 115

class MaintenanceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Stats indicates the type of aggregate and the corresponding aggregates.
  # @!attribute [rw] group_by
  #   @return [::String]
  #     groupBy specifies the type of aggregate.
  #     For example a group_by might be `"state"`
  # @!attribute [rw] aggregates
  #   @return [::Array<::Google::Cloud::Maintenance::Api::V1::MaintenanceSummary::Aggregate>]
  #     Aggregates is a list <group, count> pairs. For example, if the
  #     group_by is `"state"` a possible tuple in the aggregates list could be
  #     "SCHEDULED" : `11`,
  class Stats
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Aggregate is a <group, count> pair.
  # @!attribute [rw] group
  #   @return [::String]
  #     Specifies what specific value of the group_by the count represents. For
  #     example if group_by is `"state"` its corresponding group could be
  #     `"SCHEDULED"`.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The count of the group.
  class Aggregate
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#stats::Array<::Google::Cloud::Maintenance::Api::V1::MaintenanceSummary::Stats> (readonly)

Returns Output only. Stats is a field of ResourceMaintenance used to aggregate the stats.

Returns:



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 115

class MaintenanceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Stats indicates the type of aggregate and the corresponding aggregates.
  # @!attribute [rw] group_by
  #   @return [::String]
  #     groupBy specifies the type of aggregate.
  #     For example a group_by might be `"state"`
  # @!attribute [rw] aggregates
  #   @return [::Array<::Google::Cloud::Maintenance::Api::V1::MaintenanceSummary::Aggregate>]
  #     Aggregates is a list <group, count> pairs. For example, if the
  #     group_by is `"state"` a possible tuple in the aggregates list could be
  #     "SCHEDULED" : `11`,
  class Stats
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Aggregate is a <group, count> pair.
  # @!attribute [rw] group
  #   @return [::String]
  #     Specifies what specific value of the group_by the count represents. For
  #     example if group_by is `"state"` its corresponding group could be
  #     `"SCHEDULED"`.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The count of the group.
  class Aggregate
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#title::String (readonly)

Returns Output only. The title of the maintenance.

Returns:

  • (::String)

    Output only. The title of the maintenance.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 115

class MaintenanceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Stats indicates the type of aggregate and the corresponding aggregates.
  # @!attribute [rw] group_by
  #   @return [::String]
  #     groupBy specifies the type of aggregate.
  #     For example a group_by might be `"state"`
  # @!attribute [rw] aggregates
  #   @return [::Array<::Google::Cloud::Maintenance::Api::V1::MaintenanceSummary::Aggregate>]
  #     Aggregates is a list <group, count> pairs. For example, if the
  #     group_by is `"state"` a possible tuple in the aggregates list could be
  #     "SCHEDULED" : `11`,
  class Stats
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Aggregate is a <group, count> pair.
  # @!attribute [rw] group
  #   @return [::String]
  #     Specifies what specific value of the group_by the count represents. For
  #     example if group_by is `"state"` its corresponding group could be
  #     `"SCHEDULED"`.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The count of the group.
  class Aggregate
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#user_controllable::Boolean (readonly)

Returns Output only. Indicates whether the user has some control over that maintenance, either proactively before maintenance was scheduled with maintenance policy or with reactive controls after it was scheduled (see controls field).

Returns:

  • (::Boolean)

    Output only. Indicates whether the user has some control over that maintenance, either proactively before maintenance was scheduled with maintenance policy or with reactive controls after it was scheduled (see controls field).



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 115

class MaintenanceSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Stats indicates the type of aggregate and the corresponding aggregates.
  # @!attribute [rw] group_by
  #   @return [::String]
  #     groupBy specifies the type of aggregate.
  #     For example a group_by might be `"state"`
  # @!attribute [rw] aggregates
  #   @return [::Array<::Google::Cloud::Maintenance::Api::V1::MaintenanceSummary::Aggregate>]
  #     Aggregates is a list <group, count> pairs. For example, if the
  #     group_by is `"state"` a possible tuple in the aggregates list could be
  #     "SCHEDULED" : `11`,
  class Stats
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Aggregate is a <group, count> pair.
  # @!attribute [rw] group
  #   @return [::String]
  #     Specifies what specific value of the group_by the count represents. For
  #     example if group_by is `"state"` its corresponding group could be
  #     `"SCHEDULED"`.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     The count of the group.
  class Aggregate
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end