Class: Google::Cloud::Maintenance::Api::V1::MaintenanceSummary::Stats

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb

Overview

Stats indicates the type of aggregate and the corresponding aggregates.

Instance Attribute Summary collapse

Instance Attribute Details

#aggregates::Array<::Google::Cloud::Maintenance::Api::V1::MaintenanceSummary::Aggregate>

Returns Aggregates is a list pairs. For example, if the group_by is "state" a possible tuple in the aggregates list could be "SCHEDULED" : 11,.

Returns:



129
130
131
132
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 129

class Stats
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#group_by::String

Returns groupBy specifies the type of aggregate. For example a group_by might be "state".

Returns:

  • (::String)

    groupBy specifies the type of aggregate. For example a group_by might be "state"



129
130
131
132
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 129

class Stats
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end