Class: Google::Cloud::Maintenance::Api::V1::ResourceMaintenance
- Inherits:
-
Object
- Object
- Google::Cloud::Maintenance::Api::V1::ResourceMaintenance
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb
Overview
ResourceMaintenance is a resource that represents a maintenance operation on a resource.
Defined Under Namespace
Modules: State Classes: AnnotationsEntry, LabelsEntry, Maintenance, Resource
Instance Attribute Summary collapse
-
#annotations ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#controls ⇒ ::Array<::Google::Cloud::Maintenance::Api::V1::MaintenanceControl>
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#etag ⇒ ::String
readonly
Output only.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#maintenance ⇒ ::Google::Cloud::Maintenance::Api::V1::ResourceMaintenance::Maintenance
readonly
Output only.
-
#maintenance_cancel_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#maintenance_end_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#maintenance_scheduled_end_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#maintenance_scheduled_start_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#maintenance_start_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#resource ⇒ ::Google::Cloud::Maintenance::Api::V1::ResourceMaintenance::Resource
readonly
Output only.
-
#state ⇒ ::Google::Cloud::Maintenance::Api::V1::ResourceMaintenance::State
readonly
Output only.
-
#uid ⇒ ::String
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#user_controllable ⇒ ::Boolean
readonly
Output only.
Instance Attribute Details
#annotations ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects.
More info: https://kubernetes.io/docs/user-guide/annotations.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 221 class ResourceMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Resource contains information about the resource affected by maintenance. # @!attribute [r] resource_name # @return [::String] # Output only. Name is the reference to the consumer resource affected by # the maintenance. Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-names # @!attribute [r] location # @return [::String] # Output only. The location of the resource. # Format: # `us-central1` # @!attribute [r] type # @return [::String] # Output only. The type of the resource. # Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-types#supported_resource_types # Please note that not all the resource types will have their maintenances # reported. class Resource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Maintenance is the maintenance details of a resource's maintenance. # @!attribute [rw] maintenance_name # @return [::String] # Maintenance is the name of the corresponding maintenance resource # following the standard naming scheme: `"{maintenance-id}"` # @!attribute [r] title # @return [::String] # Output only. The title of the maintenance. # @!attribute [r] description # @return [::String] # Output only. The description of the maintenance. # @!attribute [r] category # @return [::Google::Cloud::Maintenance::Api::V1::MaintenanceCategory] # Output only. The category of the maintenance. class Maintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State is the state of a resource maintenance. module State # Unspecified state. STATE_UNSPECIFIED = 0 # Scheduled for a particular window. For disruptive maintenance it should # respect maintenance policy, i.e. its available windows, exclusions and # notification period. SCHEDULED = 1 # Maintenance is ongoing. RUNNING = 2 # No longer planned, typically when other maintenance (e.g. upgrade to # newer version) already happened, or the user skipped the maintenance. CANCELLED = 3 # Successfully completed. SUCCEEDED = 4 end end |
#controls ⇒ ::Array<::Google::Cloud::Maintenance::Api::V1::MaintenanceControl> (readonly)
Returns Output only. The controls of the maintenance.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 221 class ResourceMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Resource contains information about the resource affected by maintenance. # @!attribute [r] resource_name # @return [::String] # Output only. Name is the reference to the consumer resource affected by # the maintenance. Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-names # @!attribute [r] location # @return [::String] # Output only. The location of the resource. # Format: # `us-central1` # @!attribute [r] type # @return [::String] # Output only. The type of the resource. # Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-types#supported_resource_types # Please note that not all the resource types will have their maintenances # reported. class Resource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Maintenance is the maintenance details of a resource's maintenance. # @!attribute [rw] maintenance_name # @return [::String] # Maintenance is the name of the corresponding maintenance resource # following the standard naming scheme: `"{maintenance-id}"` # @!attribute [r] title # @return [::String] # Output only. The title of the maintenance. # @!attribute [r] description # @return [::String] # Output only. The description of the maintenance. # @!attribute [r] category # @return [::Google::Cloud::Maintenance::Api::V1::MaintenanceCategory] # Output only. The category of the maintenance. class Maintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State is the state of a resource maintenance. module State # Unspecified state. STATE_UNSPECIFIED = 0 # Scheduled for a particular window. For disruptive maintenance it should # respect maintenance policy, i.e. its available windows, exclusions and # notification period. SCHEDULED = 1 # Maintenance is ongoing. RUNNING = 2 # No longer planned, typically when other maintenance (e.g. upgrade to # newer version) already happened, or the user skipped the maintenance. CANCELLED = 3 # Successfully completed. SUCCEEDED = 4 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The create time of the resource maintenance.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 221 class ResourceMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Resource contains information about the resource affected by maintenance. # @!attribute [r] resource_name # @return [::String] # Output only. Name is the reference to the consumer resource affected by # the maintenance. Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-names # @!attribute [r] location # @return [::String] # Output only. The location of the resource. # Format: # `us-central1` # @!attribute [r] type # @return [::String] # Output only. The type of the resource. # Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-types#supported_resource_types # Please note that not all the resource types will have their maintenances # reported. class Resource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Maintenance is the maintenance details of a resource's maintenance. # @!attribute [rw] maintenance_name # @return [::String] # Maintenance is the name of the corresponding maintenance resource # following the standard naming scheme: `"{maintenance-id}"` # @!attribute [r] title # @return [::String] # Output only. The title of the maintenance. # @!attribute [r] description # @return [::String] # Output only. The description of the maintenance. # @!attribute [r] category # @return [::Google::Cloud::Maintenance::Api::V1::MaintenanceCategory] # Output only. The category of the maintenance. class Maintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State is the state of a resource maintenance. module State # Unspecified state. STATE_UNSPECIFIED = 0 # Scheduled for a particular window. For disruptive maintenance it should # respect maintenance policy, i.e. its available windows, exclusions and # notification period. SCHEDULED = 1 # Maintenance is ongoing. RUNNING = 2 # No longer planned, typically when other maintenance (e.g. upgrade to # newer version) already happened, or the user skipped the maintenance. CANCELLED = 3 # Successfully completed. SUCCEEDED = 4 end end |
#etag ⇒ ::String (readonly)
Returns Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 221 class ResourceMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Resource contains information about the resource affected by maintenance. # @!attribute [r] resource_name # @return [::String] # Output only. Name is the reference to the consumer resource affected by # the maintenance. Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-names # @!attribute [r] location # @return [::String] # Output only. The location of the resource. # Format: # `us-central1` # @!attribute [r] type # @return [::String] # Output only. The type of the resource. # Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-types#supported_resource_types # Please note that not all the resource types will have their maintenances # reported. class Resource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Maintenance is the maintenance details of a resource's maintenance. # @!attribute [rw] maintenance_name # @return [::String] # Maintenance is the name of the corresponding maintenance resource # following the standard naming scheme: `"{maintenance-id}"` # @!attribute [r] title # @return [::String] # Output only. The title of the maintenance. # @!attribute [r] description # @return [::String] # Output only. The description of the maintenance. # @!attribute [r] category # @return [::Google::Cloud::Maintenance::Api::V1::MaintenanceCategory] # Output only. The category of the maintenance. class Maintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State is the state of a resource maintenance. module State # Unspecified state. STATE_UNSPECIFIED = 0 # Scheduled for a particular window. For disruptive maintenance it should # respect maintenance policy, i.e. its available windows, exclusions and # notification period. SCHEDULED = 1 # Maintenance is ongoing. RUNNING = 2 # No longer planned, typically when other maintenance (e.g. upgrade to # newer version) already happened, or the user skipped the maintenance. CANCELLED = 3 # Successfully completed. SUCCEEDED = 4 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 221 class ResourceMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Resource contains information about the resource affected by maintenance. # @!attribute [r] resource_name # @return [::String] # Output only. Name is the reference to the consumer resource affected by # the maintenance. Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-names # @!attribute [r] location # @return [::String] # Output only. The location of the resource. # Format: # `us-central1` # @!attribute [r] type # @return [::String] # Output only. The type of the resource. # Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-types#supported_resource_types # Please note that not all the resource types will have their maintenances # reported. class Resource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Maintenance is the maintenance details of a resource's maintenance. # @!attribute [rw] maintenance_name # @return [::String] # Maintenance is the name of the corresponding maintenance resource # following the standard naming scheme: `"{maintenance-id}"` # @!attribute [r] title # @return [::String] # Output only. The title of the maintenance. # @!attribute [r] description # @return [::String] # Output only. The description of the maintenance. # @!attribute [r] category # @return [::Google::Cloud::Maintenance::Api::V1::MaintenanceCategory] # Output only. The category of the maintenance. class Maintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State is the state of a resource maintenance. module State # Unspecified state. STATE_UNSPECIFIED = 0 # Scheduled for a particular window. For disruptive maintenance it should # respect maintenance policy, i.e. its available windows, exclusions and # notification period. SCHEDULED = 1 # Maintenance is ongoing. RUNNING = 2 # No longer planned, typically when other maintenance (e.g. upgrade to # newer version) already happened, or the user skipped the maintenance. CANCELLED = 3 # Successfully completed. SUCCEEDED = 4 end end |
#maintenance ⇒ ::Google::Cloud::Maintenance::Api::V1::ResourceMaintenance::Maintenance (readonly)
Returns Output only. The details of the maintenance.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 221 class ResourceMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Resource contains information about the resource affected by maintenance. # @!attribute [r] resource_name # @return [::String] # Output only. Name is the reference to the consumer resource affected by # the maintenance. Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-names # @!attribute [r] location # @return [::String] # Output only. The location of the resource. # Format: # `us-central1` # @!attribute [r] type # @return [::String] # Output only. The type of the resource. # Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-types#supported_resource_types # Please note that not all the resource types will have their maintenances # reported. class Resource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Maintenance is the maintenance details of a resource's maintenance. # @!attribute [rw] maintenance_name # @return [::String] # Maintenance is the name of the corresponding maintenance resource # following the standard naming scheme: `"{maintenance-id}"` # @!attribute [r] title # @return [::String] # Output only. The title of the maintenance. # @!attribute [r] description # @return [::String] # Output only. The description of the maintenance. # @!attribute [r] category # @return [::Google::Cloud::Maintenance::Api::V1::MaintenanceCategory] # Output only. The category of the maintenance. class Maintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State is the state of a resource maintenance. module State # Unspecified state. STATE_UNSPECIFIED = 0 # Scheduled for a particular window. For disruptive maintenance it should # respect maintenance policy, i.e. its available windows, exclusions and # notification period. SCHEDULED = 1 # Maintenance is ongoing. RUNNING = 2 # No longer planned, typically when other maintenance (e.g. upgrade to # newer version) already happened, or the user skipped the maintenance. CANCELLED = 3 # Successfully completed. SUCCEEDED = 4 end end |
#maintenance_cancel_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time when the resource maintenance was cancelled.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 221 class ResourceMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Resource contains information about the resource affected by maintenance. # @!attribute [r] resource_name # @return [::String] # Output only. Name is the reference to the consumer resource affected by # the maintenance. Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-names # @!attribute [r] location # @return [::String] # Output only. The location of the resource. # Format: # `us-central1` # @!attribute [r] type # @return [::String] # Output only. The type of the resource. # Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-types#supported_resource_types # Please note that not all the resource types will have their maintenances # reported. class Resource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Maintenance is the maintenance details of a resource's maintenance. # @!attribute [rw] maintenance_name # @return [::String] # Maintenance is the name of the corresponding maintenance resource # following the standard naming scheme: `"{maintenance-id}"` # @!attribute [r] title # @return [::String] # Output only. The title of the maintenance. # @!attribute [r] description # @return [::String] # Output only. The description of the maintenance. # @!attribute [r] category # @return [::Google::Cloud::Maintenance::Api::V1::MaintenanceCategory] # Output only. The category of the maintenance. class Maintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State is the state of a resource maintenance. module State # Unspecified state. STATE_UNSPECIFIED = 0 # Scheduled for a particular window. For disruptive maintenance it should # respect maintenance policy, i.e. its available windows, exclusions and # notification period. SCHEDULED = 1 # Maintenance is ongoing. RUNNING = 2 # No longer planned, typically when other maintenance (e.g. upgrade to # newer version) already happened, or the user skipped the maintenance. CANCELLED = 3 # Successfully completed. SUCCEEDED = 4 end end |
#maintenance_end_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time when the resource maintenance has completed.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 221 class ResourceMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Resource contains information about the resource affected by maintenance. # @!attribute [r] resource_name # @return [::String] # Output only. Name is the reference to the consumer resource affected by # the maintenance. Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-names # @!attribute [r] location # @return [::String] # Output only. The location of the resource. # Format: # `us-central1` # @!attribute [r] type # @return [::String] # Output only. The type of the resource. # Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-types#supported_resource_types # Please note that not all the resource types will have their maintenances # reported. class Resource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Maintenance is the maintenance details of a resource's maintenance. # @!attribute [rw] maintenance_name # @return [::String] # Maintenance is the name of the corresponding maintenance resource # following the standard naming scheme: `"{maintenance-id}"` # @!attribute [r] title # @return [::String] # Output only. The title of the maintenance. # @!attribute [r] description # @return [::String] # Output only. The description of the maintenance. # @!attribute [r] category # @return [::Google::Cloud::Maintenance::Api::V1::MaintenanceCategory] # Output only. The category of the maintenance. class Maintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State is the state of a resource maintenance. module State # Unspecified state. STATE_UNSPECIFIED = 0 # Scheduled for a particular window. For disruptive maintenance it should # respect maintenance policy, i.e. its available windows, exclusions and # notification period. SCHEDULED = 1 # Maintenance is ongoing. RUNNING = 2 # No longer planned, typically when other maintenance (e.g. upgrade to # newer version) already happened, or the user skipped the maintenance. CANCELLED = 3 # Successfully completed. SUCCEEDED = 4 end end |
#maintenance_scheduled_end_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time when the maintenance on the resource was scheduled to end.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 221 class ResourceMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Resource contains information about the resource affected by maintenance. # @!attribute [r] resource_name # @return [::String] # Output only. Name is the reference to the consumer resource affected by # the maintenance. Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-names # @!attribute [r] location # @return [::String] # Output only. The location of the resource. # Format: # `us-central1` # @!attribute [r] type # @return [::String] # Output only. The type of the resource. # Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-types#supported_resource_types # Please note that not all the resource types will have their maintenances # reported. class Resource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Maintenance is the maintenance details of a resource's maintenance. # @!attribute [rw] maintenance_name # @return [::String] # Maintenance is the name of the corresponding maintenance resource # following the standard naming scheme: `"{maintenance-id}"` # @!attribute [r] title # @return [::String] # Output only. The title of the maintenance. # @!attribute [r] description # @return [::String] # Output only. The description of the maintenance. # @!attribute [r] category # @return [::Google::Cloud::Maintenance::Api::V1::MaintenanceCategory] # Output only. The category of the maintenance. class Maintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State is the state of a resource maintenance. module State # Unspecified state. STATE_UNSPECIFIED = 0 # Scheduled for a particular window. For disruptive maintenance it should # respect maintenance policy, i.e. its available windows, exclusions and # notification period. SCHEDULED = 1 # Maintenance is ongoing. RUNNING = 2 # No longer planned, typically when other maintenance (e.g. upgrade to # newer version) already happened, or the user skipped the maintenance. CANCELLED = 3 # Successfully completed. SUCCEEDED = 4 end end |
#maintenance_scheduled_start_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time when the maintenance on the resource was scheduled to start.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 221 class ResourceMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Resource contains information about the resource affected by maintenance. # @!attribute [r] resource_name # @return [::String] # Output only. Name is the reference to the consumer resource affected by # the maintenance. Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-names # @!attribute [r] location # @return [::String] # Output only. The location of the resource. # Format: # `us-central1` # @!attribute [r] type # @return [::String] # Output only. The type of the resource. # Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-types#supported_resource_types # Please note that not all the resource types will have their maintenances # reported. class Resource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Maintenance is the maintenance details of a resource's maintenance. # @!attribute [rw] maintenance_name # @return [::String] # Maintenance is the name of the corresponding maintenance resource # following the standard naming scheme: `"{maintenance-id}"` # @!attribute [r] title # @return [::String] # Output only. The title of the maintenance. # @!attribute [r] description # @return [::String] # Output only. The description of the maintenance. # @!attribute [r] category # @return [::Google::Cloud::Maintenance::Api::V1::MaintenanceCategory] # Output only. The category of the maintenance. class Maintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State is the state of a resource maintenance. module State # Unspecified state. STATE_UNSPECIFIED = 0 # Scheduled for a particular window. For disruptive maintenance it should # respect maintenance policy, i.e. its available windows, exclusions and # notification period. SCHEDULED = 1 # Maintenance is ongoing. RUNNING = 2 # No longer planned, typically when other maintenance (e.g. upgrade to # newer version) already happened, or the user skipped the maintenance. CANCELLED = 3 # Successfully completed. SUCCEEDED = 4 end end |
#maintenance_start_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time when the resource maintenance has started.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 221 class ResourceMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Resource contains information about the resource affected by maintenance. # @!attribute [r] resource_name # @return [::String] # Output only. Name is the reference to the consumer resource affected by # the maintenance. Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-names # @!attribute [r] location # @return [::String] # Output only. The location of the resource. # Format: # `us-central1` # @!attribute [r] type # @return [::String] # Output only. The type of the resource. # Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-types#supported_resource_types # Please note that not all the resource types will have their maintenances # reported. class Resource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Maintenance is the maintenance details of a resource's maintenance. # @!attribute [rw] maintenance_name # @return [::String] # Maintenance is the name of the corresponding maintenance resource # following the standard naming scheme: `"{maintenance-id}"` # @!attribute [r] title # @return [::String] # Output only. The title of the maintenance. # @!attribute [r] description # @return [::String] # Output only. The description of the maintenance. # @!attribute [r] category # @return [::Google::Cloud::Maintenance::Api::V1::MaintenanceCategory] # Output only. The category of the maintenance. class Maintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State is the state of a resource maintenance. module State # Unspecified state. STATE_UNSPECIFIED = 0 # Scheduled for a particular window. For disruptive maintenance it should # respect maintenance policy, i.e. its available windows, exclusions and # notification period. SCHEDULED = 1 # Maintenance is ongoing. RUNNING = 2 # No longer planned, typically when other maintenance (e.g. upgrade to # newer version) already happened, or the user skipped the maintenance. CANCELLED = 3 # Successfully completed. SUCCEEDED = 4 end end |
#name ⇒ ::String
Returns Identifier. The name of the resource_maintenance resource.
Format:
"projects/{project}/locations/{location}/resourceMaintenance/{resource-maintenance-id}".
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 221 class ResourceMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Resource contains information about the resource affected by maintenance. # @!attribute [r] resource_name # @return [::String] # Output only. Name is the reference to the consumer resource affected by # the maintenance. Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-names # @!attribute [r] location # @return [::String] # Output only. The location of the resource. # Format: # `us-central1` # @!attribute [r] type # @return [::String] # Output only. The type of the resource. # Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-types#supported_resource_types # Please note that not all the resource types will have their maintenances # reported. class Resource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Maintenance is the maintenance details of a resource's maintenance. # @!attribute [rw] maintenance_name # @return [::String] # Maintenance is the name of the corresponding maintenance resource # following the standard naming scheme: `"{maintenance-id}"` # @!attribute [r] title # @return [::String] # Output only. The title of the maintenance. # @!attribute [r] description # @return [::String] # Output only. The description of the maintenance. # @!attribute [r] category # @return [::Google::Cloud::Maintenance::Api::V1::MaintenanceCategory] # Output only. The category of the maintenance. class Maintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State is the state of a resource maintenance. module State # Unspecified state. STATE_UNSPECIFIED = 0 # Scheduled for a particular window. For disruptive maintenance it should # respect maintenance policy, i.e. its available windows, exclusions and # notification period. SCHEDULED = 1 # Maintenance is ongoing. RUNNING = 2 # No longer planned, typically when other maintenance (e.g. upgrade to # newer version) already happened, or the user skipped the maintenance. CANCELLED = 3 # Successfully completed. SUCCEEDED = 4 end end |
#resource ⇒ ::Google::Cloud::Maintenance::Api::V1::ResourceMaintenance::Resource (readonly)
Returns Output only. The resource spec of the resource maintenance.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 221 class ResourceMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Resource contains information about the resource affected by maintenance. # @!attribute [r] resource_name # @return [::String] # Output only. Name is the reference to the consumer resource affected by # the maintenance. Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-names # @!attribute [r] location # @return [::String] # Output only. The location of the resource. # Format: # `us-central1` # @!attribute [r] type # @return [::String] # Output only. The type of the resource. # Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-types#supported_resource_types # Please note that not all the resource types will have their maintenances # reported. class Resource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Maintenance is the maintenance details of a resource's maintenance. # @!attribute [rw] maintenance_name # @return [::String] # Maintenance is the name of the corresponding maintenance resource # following the standard naming scheme: `"{maintenance-id}"` # @!attribute [r] title # @return [::String] # Output only. The title of the maintenance. # @!attribute [r] description # @return [::String] # Output only. The description of the maintenance. # @!attribute [r] category # @return [::Google::Cloud::Maintenance::Api::V1::MaintenanceCategory] # Output only. The category of the maintenance. class Maintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State is the state of a resource maintenance. module State # Unspecified state. STATE_UNSPECIFIED = 0 # Scheduled for a particular window. For disruptive maintenance it should # respect maintenance policy, i.e. its available windows, exclusions and # notification period. SCHEDULED = 1 # Maintenance is ongoing. RUNNING = 2 # No longer planned, typically when other maintenance (e.g. upgrade to # newer version) already happened, or the user skipped the maintenance. CANCELLED = 3 # Successfully completed. SUCCEEDED = 4 end end |
#state ⇒ ::Google::Cloud::Maintenance::Api::V1::ResourceMaintenance::State (readonly)
Returns Output only. The state of the resource maintenance.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 221 class ResourceMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Resource contains information about the resource affected by maintenance. # @!attribute [r] resource_name # @return [::String] # Output only. Name is the reference to the consumer resource affected by # the maintenance. Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-names # @!attribute [r] location # @return [::String] # Output only. The location of the resource. # Format: # `us-central1` # @!attribute [r] type # @return [::String] # Output only. The type of the resource. # Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-types#supported_resource_types # Please note that not all the resource types will have their maintenances # reported. class Resource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Maintenance is the maintenance details of a resource's maintenance. # @!attribute [rw] maintenance_name # @return [::String] # Maintenance is the name of the corresponding maintenance resource # following the standard naming scheme: `"{maintenance-id}"` # @!attribute [r] title # @return [::String] # Output only. The title of the maintenance. # @!attribute [r] description # @return [::String] # Output only. The description of the maintenance. # @!attribute [r] category # @return [::Google::Cloud::Maintenance::Api::V1::MaintenanceCategory] # Output only. The category of the maintenance. class Maintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State is the state of a resource maintenance. module State # Unspecified state. STATE_UNSPECIFIED = 0 # Scheduled for a particular window. For disruptive maintenance it should # respect maintenance policy, i.e. its available windows, exclusions and # notification period. SCHEDULED = 1 # Maintenance is ongoing. RUNNING = 2 # No longer planned, typically when other maintenance (e.g. upgrade to # newer version) already happened, or the user skipped the maintenance. CANCELLED = 3 # Successfully completed. SUCCEEDED = 4 end end |
#uid ⇒ ::String (readonly)
Returns Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 221 class ResourceMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Resource contains information about the resource affected by maintenance. # @!attribute [r] resource_name # @return [::String] # Output only. Name is the reference to the consumer resource affected by # the maintenance. Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-names # @!attribute [r] location # @return [::String] # Output only. The location of the resource. # Format: # `us-central1` # @!attribute [r] type # @return [::String] # Output only. The type of the resource. # Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-types#supported_resource_types # Please note that not all the resource types will have their maintenances # reported. class Resource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Maintenance is the maintenance details of a resource's maintenance. # @!attribute [rw] maintenance_name # @return [::String] # Maintenance is the name of the corresponding maintenance resource # following the standard naming scheme: `"{maintenance-id}"` # @!attribute [r] title # @return [::String] # Output only. The title of the maintenance. # @!attribute [r] description # @return [::String] # Output only. The description of the maintenance. # @!attribute [r] category # @return [::Google::Cloud::Maintenance::Api::V1::MaintenanceCategory] # Output only. The category of the maintenance. class Maintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State is the state of a resource maintenance. module State # Unspecified state. STATE_UNSPECIFIED = 0 # Scheduled for a particular window. For disruptive maintenance it should # respect maintenance policy, i.e. its available windows, exclusions and # notification period. SCHEDULED = 1 # Maintenance is ongoing. RUNNING = 2 # No longer planned, typically when other maintenance (e.g. upgrade to # newer version) already happened, or the user skipped the maintenance. CANCELLED = 3 # Successfully completed. SUCCEEDED = 4 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The update time of the resource maintenance.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 221 class ResourceMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Resource contains information about the resource affected by maintenance. # @!attribute [r] resource_name # @return [::String] # Output only. Name is the reference to the consumer resource affected by # the maintenance. Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-names # @!attribute [r] location # @return [::String] # Output only. The location of the resource. # Format: # `us-central1` # @!attribute [r] type # @return [::String] # Output only. The type of the resource. # Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-types#supported_resource_types # Please note that not all the resource types will have their maintenances # reported. class Resource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Maintenance is the maintenance details of a resource's maintenance. # @!attribute [rw] maintenance_name # @return [::String] # Maintenance is the name of the corresponding maintenance resource # following the standard naming scheme: `"{maintenance-id}"` # @!attribute [r] title # @return [::String] # Output only. The title of the maintenance. # @!attribute [r] description # @return [::String] # Output only. The description of the maintenance. # @!attribute [r] category # @return [::Google::Cloud::Maintenance::Api::V1::MaintenanceCategory] # Output only. The category of the maintenance. class Maintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State is the state of a resource maintenance. module State # Unspecified state. STATE_UNSPECIFIED = 0 # Scheduled for a particular window. For disruptive maintenance it should # respect maintenance policy, i.e. its available windows, exclusions and # notification period. SCHEDULED = 1 # Maintenance is ongoing. RUNNING = 2 # No longer planned, typically when other maintenance (e.g. upgrade to # newer version) already happened, or the user skipped the maintenance. CANCELLED = 3 # Successfully completed. SUCCEEDED = 4 end end |
#user_controllable ⇒ ::Boolean (readonly)
Returns Output only. Indicates whether the user has some control over that maintenance, either proactively before maintenance was scheduled with maintenance policy or with reactive controls after it was scheduled (see controls field).
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 221 class ResourceMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Resource contains information about the resource affected by maintenance. # @!attribute [r] resource_name # @return [::String] # Output only. Name is the reference to the consumer resource affected by # the maintenance. Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-names # @!attribute [r] location # @return [::String] # Output only. The location of the resource. # Format: # `us-central1` # @!attribute [r] type # @return [::String] # Output only. The type of the resource. # Available values can be found here: # https://cloud.google.com/asset-inventory/docs/asset-types#supported_resource_types # Please note that not all the resource types will have their maintenances # reported. class Resource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Maintenance is the maintenance details of a resource's maintenance. # @!attribute [rw] maintenance_name # @return [::String] # Maintenance is the name of the corresponding maintenance resource # following the standard naming scheme: `"{maintenance-id}"` # @!attribute [r] title # @return [::String] # Output only. The title of the maintenance. # @!attribute [r] description # @return [::String] # Output only. The description of the maintenance. # @!attribute [r] category # @return [::Google::Cloud::Maintenance::Api::V1::MaintenanceCategory] # Output only. The category of the maintenance. class Maintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State is the state of a resource maintenance. module State # Unspecified state. STATE_UNSPECIFIED = 0 # Scheduled for a particular window. For disruptive maintenance it should # respect maintenance policy, i.e. its available windows, exclusions and # notification period. SCHEDULED = 1 # Maintenance is ongoing. RUNNING = 2 # No longer planned, typically when other maintenance (e.g. upgrade to # newer version) already happened, or the user skipped the maintenance. CANCELLED = 3 # Successfully completed. SUCCEEDED = 4 end end |