Class: Google::Cloud::Maintenance::Api::V1::SummarizeMaintenancesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb

Overview

Request message for SummarizeMaintenances custom method.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Filter the list as specified in https://google.aip.dev/160. Supported fields include:

  • maintenance.maintenanceName Examples:
  • maintenance.maintenanceName="eb3b709c-9ca1-5472-9fb6-800a3849eda1".

Returns:

  • (::String)

    Filter the list as specified in https://google.aip.dev/160. Supported fields include:

    • maintenance.maintenanceName Examples:
    • maintenance.maintenanceName="eb3b709c-9ca1-5472-9fb6-800a3849eda1"


48
49
50
51
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 48

class SummarizeMaintenancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Order results as specified in https://google.aip.dev/132.

Returns:



48
49
50
51
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 48

class SummarizeMaintenancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns The maximum number of resource maintenances to send per page. The default page size is 20 and the maximum is 1000.

Returns:

  • (::Integer)

    The maximum number of resource maintenances to send per page. The default page size is 20 and the maximum is 1000.



48
49
50
51
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 48

class SummarizeMaintenancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns The page token: If the next_page_token from a previous response is provided, this request will send the subsequent page.

Returns:

  • (::String)

    The page token: If the next_page_token from a previous response is provided, this request will send the subsequent page.



48
49
50
51
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 48

class SummarizeMaintenancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent of the resource maintenance. eg. projects/123/locations/*.

Returns:

  • (::String)

    Required. The parent of the resource maintenance. eg. projects/123/locations/*



48
49
50
51
# File 'proto_docs/google/cloud/maintenance/api/v1/maintenance_service.rb', line 48

class SummarizeMaintenancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end